#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-AKJFoSC7WYyJQ5HCM4FzzK
key:                  aeson-yaml-1.1.0.1-AKJFoSC7WYyJQ5HCM4FzzK
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  c4678036e4aed014904351817d9f8e8a
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-AKJFoSC7WYyJQ5HCM4FzzK
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

